@@ -5,12 +5,12 @@ Catmandu::Exporter::MARC - Exporter for MARC records
 =head1 SYNOPSIS
 
     # From the command line
-    $ catmandu convert MARC --type USMARC to MARC --type XML < /foo/bar.mrc
+    $ catmandu convert MARC --type ISO to MARC --type XML < /foo/bar.mrc
 
     # From Perl
     use Catmandu;
 
-    my $importer = Catmandu->importer('MARC', file => "/foo/bar.mrc" , type => 'USMARC');
+    my $importer = Catmandu->importer('MARC', file => "/foo/bar.mrc" , type => 'ISO');
     my $exporter = Catmandu->exporter('MARC', file => "marc.xml", type => "XML" );
 
     $exporter->add($importer);
@@ -29,12 +29,21 @@ to a file or the standard output.
 
 Create a new MARC exporter of the given type. Currently we support:
 
-    USMARC    L<Catmandu::Exporter::MARC::USMARC>
-    ISO       alias for USMARC
-    XML       L<Catmandu::Exporter::MARC::XML>
-    MARCMaker L<Catmandu::Exporter::MARC::MARCMaker>
-    MiJ       L<Catmandu::Exporter::MARC::MiJ> (Marc in Json)
-    ALEPHSEQ  L<Catmandu::Exporter::MARC::ALEPHSEQ>
+=over
+
+=item * USMARC: alias for ISO, B<deprecated, will be removed in future version>
+
+=item * ISO: L<Catmandu::Importer::MARC::ISO>
+
+=item * XML: L<Catmandu::Exporter::MARC::XML>
+
+=item * MARCMaker: L<Catmandu::Exporter::MARC::MARCMaker>
+
+=item * MiJ: L<Catmandu::Exporter::MARC::MiJ> (Marc in Json)
+
+=item * ALEPHSEQ: L<Catmandu::Exporter::MARC::ALEPHSEQ>
+
+=back
 
 =item file
 
@@ -67,15 +76,16 @@ package Catmandu::Exporter::MARC;
 use Catmandu::Sane;
 use Moo;
 
-our $VERSION = '0.219';
+our $VERSION = '1.01';
 
-has type           => (is => 'ro' , default => sub { 'XML' });
+has type           => (is => 'ro' , default => sub { 'ISO' });
 has _exporter      => (is => 'ro' , lazy => 1 , builder => '_build_exporter' , handles => 'Catmandu::Exporter');
 has _exporter_args => (is => 'rwp', writer => '_set_exporter_args');
 
 sub _build_exporter {
     my ($self) = @_;
-    my $type = $self->type eq 'ISO' ? 'USMARC' : $self->type;
+
+    my $type = $self->type;
 
     my $pkg = Catmandu::Util::require_package($type,'Catmandu::Exporter::MARC');
 
@@ -85,6 +95,13 @@ sub _build_exporter {
 sub BUILD {
     my ($self,$args) = @_;
     $self->_set_exporter_args($args);
+
+    # keep USMARC temporary as alias for ISO, remove in future version
+    # print deprecation warning
+    if ($self->{type} eq 'USMARC') {
+        $self->{type} = 'ISO';
+        warn( "deprecated", "Oops! Exporter \"USMARC\" is deprecated. Use \"ISO\" instead." );
+    }
 }
 
 1;
