@@ -3,7 +3,7 @@ use Catmandu::Sane;
 use Catmandu::Util qw(xml_escape is_different :array :is);
 use Moo;
 
-our $VERSION = '0.219';
+our $VERSION = '1.01';
 
 with 'Catmandu::Exporter', 'Catmandu::Exporter::MARC::Base';
 
@@ -112,7 +112,7 @@ Catmandu::Exporter::MARC::XML - Exporter for MARC records to MARCXML
     # From Perl
     use Catmandu;
 
-    my $importer = Catmandu->importer('MARC', file => "/foo/bar.mrc" , type => 'USMARC');
+    my $importer = Catmandu->importer('MARC', file => "/foo/bar.mrc" , type => 'ISO');
     my $exporter = Catmandu->exporter('MARC', file => "marc.xml", type => 'XML' );
 
     $exporter->add($importer);
