@@ -2,29 +2,20 @@ package Catmandu::Fix::marc_xml;
 
 use Catmandu::Sane;
 use Moo;
-use IO::String;
-use Catmandu::Exporter::MARC::XML;
-use Catmandu::Util qw(:is :data);
+use Catmandu::MARC;
 use Catmandu::Fix::Has;
 
 with 'Catmandu::Fix::Inlineable';
 
-our $VERSION = '0.219';
+our $VERSION = '1.01';
 
 has path  => (fix_arg => 1);
 
 # Transform a raw MARC array into MARCXML
 sub fix {
     my ($self, $data) = @_;
-    my $path    = $self->path;
-
-    my $xml;
-    my $exporter = Catmandu::Exporter::MARC::XML->new(file => \$xml , xml_declaration => 0 , collection => 0);
-    $exporter->add($data);
-    $exporter->commit;
-
-    $data->{$path} = $xml;
-
+    my $xml = Catmandu::MARC->instance->marc_xml($data);
+    $data->{$self->path} = $xml;
     $data;
 }
 
@@ -41,6 +32,22 @@ Catmandu::Fix::marc_xml - transform a Catmandu MARC record into MARCXML
 
 Convert MARC data into a MARCXML string
 
+=head1 METHODS
+
+=head2 marc_xml(PATH)
+
+Transform the MARC record found at PATH to MARC XML.
+
+=head1 INLINE
+
+This Fix can be used inline in a Perl script:
+
+    use Catmandu::Fix::marc_xml as => 'marc_xml';
+
+    my $data = { record => [...] };
+
+    $data = marc_xml($data);
+
 =head1 SEE ALSO
 
 L<Catmandu::Fix>
