@@ -4,7 +4,7 @@ Catmandu::Importer::MARC - Package that imports MARC data
 
 =head1 SYNOPSIS
 
-    # From the command line
+    # From the command line convert MARC to JSON mapping 245a to a title
     $ catmandu convert MARC --fix "marc_map('245a','title')" < /foo/bar.mrc
 
     # From Perl
@@ -70,15 +70,27 @@ Read more about processing data with Catmandu on the wiki: L<https://github.com/
 
 Create a new MARC importer of the given type. Currently we support:
 
-    USMARC    L<Catmandu::Importer::MARC::USMARC>
-    ISO       alias for USMARC
-    MicroLIF  L<Catmandu::Importer::MARC::MicroLIF>
-    MARCMaker L<Catmandu::Importer::MARC::MARCMaker>
-    MiJ       L<Catmandu::Importer::MARC::MiJ>
-    XML       L<Catmandu::Importer::MARC::XML>
-    RAW       L<Catmandu::Importer::MARC::RAW>
-    Lint      L<Catmandu::Importer::MARC::Lint>
-    ALEPHSEQ  L<Catmandu::Importer::MARC::ALEPHSEQ>
+=over
+
+=item * USMARC: alias for ISO, B<deprecated, will be removed in future version>
+
+=item * ISO: L<Catmandu::Importer::MARC::ISO>
+
+=item * MicroLIF: L<Catmandu::Importer::MARC::MicroLIF>
+
+=item * MARCMaker: L<Catmandu::Importer::MARC::MARCMaker>
+
+=item * MiJ: L<Catmandu::Importer::MARC::MiJ>
+
+=item * XML: L<Catmandu::Importer::MARC::XML>
+
+=item * RAW: L<Catmandu::Importer::MARC::RAW>
+
+=item * Lint: L<Catmandu::Importer::MARC::Lint>
+
+=item * ALEPHSEQ: L<Catmandu::Importer::MARC::ALEPHSEQ>
+
+=back
 
 =item file
 
@@ -115,9 +127,9 @@ use Catmandu::Sane;
 use Catmandu::Util;
 use Moo;
 
-our $VERSION = '0.219';
+our $VERSION = '1.01';
 
-has type           => (is => 'ro' , default => sub { 'USMARC' });
+has type           => (is => 'ro' , default => sub { 'ISO' });
 has _importer      => (is => 'ro' , lazy => 1 , builder => '_build_importer' , handles => ['generator']);
 has _importer_args => (is => 'rwp', writer => '_set_importer_args');
 
@@ -125,7 +137,8 @@ with 'Catmandu::Importer';
 
 sub _build_importer {
     my ($self) = @_;
-    my $type = $self->type eq 'ISO' ? 'USMARC' : $self->type;
+
+    my $type = $self->type;
 
     $type = 'Record' if exists $self->_importer_args->{records};
 
@@ -137,6 +150,13 @@ sub _build_importer {
 sub BUILD {
     my ($self,$args) = @_;
     $self->_set_importer_args($args);
+
+    # keep USMARC temporary as alias for ISO, remove in future version
+    # print deprecation warning
+    if ($self->{type} eq 'USMARC') {
+        $self->{type} = 'ISO';
+        warn( "deprecated", "Oops! Importer \"USMARC\" is deprecated. Use \"ISO\" instead." );
+    }
 }
 
 
